/* Exporta os dados da movimentao do caixa para o financeiro*/
IF EXISTS (SELECT
              *
           FROM SYSOBJECTS O, SYSUSERS U
           WHERE
              O.NAME = 'EXPORTA_PDV_FINANC' AND
              TYPE   = 'P'               AND
              U.UID  = O.UID             AND
              U.NAME = USER)

DROP PROCEDURE EXPORTA_PDV_FINANC
GO
CREATE PROCEDURE EXPORTA_PDV_FINANC(
   @P_CDEMPRESA    VARCHAR(2),      /*Cod. da empresa*/
   @P_CDFILIPROC   VARCHAR(4),      /*Cod. da filial de processamento*/
   @P_CDOPERADOR   VARCHAR(12),     /*Cod do operador*/
   @P_FILIORIGEM   VARCHAR(4),      /*Cod. da filial de origem*/
   @P_DTMOVIMCAIXA DATETIME,        /*Data da movimentao do caixa*/
   @P_DTVENCIMENTO DATETIME,        /*Data de vencimento do lanamento financ.*/
   @P_CDTIPORECE   VARCHAR(3),      /*Tipo de recebimento*/
   @P_NRCHEQUEVEND VARCHAR(6),      /*Num. do cheque*/
   @P_CDBANCHEQVEN VARCHAR(3),      /*Cod. do banco do cheque*/
   @P_CDAGECHEQVEN VARCHAR(5),      /*Cod. da agencia do cheque*/
   @P_CDCNTCHEQVEN VARCHAR(16),     /*Cod. do cheque*/
   @P_NRINSJURCHEQ VARCHAR(20),     /*Num. do CPF*/
   @P_VRMOVIVEND   DOUBLE PRECISION,/*Valor da movimento*/
   @P_CDCLIENTE    VARCHAR(21),     /*Cdigo do cliente(padro)*/
   @P_CDVENDEDOR   VARCHAR(4),      /*Cdigo do vendedor(opcional)*/
   @P_CDTIPOOPER   VARCHAR(2),      /*Tipo de operao*/
   @P_CDSERIE      VARCHAR(5),      /*Srie de sada*/
   @P_SOMATORIO   VARCHAR(2),      /*Tipo de somatrio*/
   @P_QTPARCELAS DOUBLE PRECISION)  /*Quantidade de parcelas*/
AS
   DECLARE @V_NRLANCTONF     VARCHAR(20);
   DECLARE @V_NRLANBOL       VARCHAR(20);
   DECLARE @V_IDTIPORECE     VARCHAR(1) ;
   DECLARE @V_DESCCONTA      VARCHAR(40);
   DECLARE @V_CDTPAJUSTE     VARCHAR(4) ;
   DECLARE @V_VRPETAXA       DOUBLE PRECISION;
   DECLARE @V_VRAJUSTE       DOUBLE PRECISION;
   DECLARE @V_CDCONTCORR     VARCHAR(3) ;
   DECLARE @V_CDTIPOBAIXA    VARCHAR(2) ;
   DECLARE @V_NMRAZSOCCLIE   VARCHAR(50);
   DECLARE @V_NRINSJURCLIE   VARCHAR(20);
   DECLARE @V_CONCAT1        VARCHAR(30);
   DECLARE @V_CONCAT2        VARCHAR(30);
   DECLARE @V_STATUS         VARCHAR(40);
   DECLARE @V_QTPARCELAS     DOUBLE PRECISION;
BEGIN
   SET @V_QTPARCELAS = @P_QTPARCELAS;
   IF (@V_QTPARCELAS IS NULL) OR (@V_QTPARCELAS = 0) BEGIN
      SET @V_QTPARCELAS = 1;
   END;
   /* Busca o nmero do lanamento da NF*/
   SET @V_CONCAT1 = 'LANCNF/FILIAL'+@P_CDFILIPROC;
   EXEC NOVO_CODIGO @V_CONCAT1, @P_SEQUENCIAL = @V_NRLANCTONF OUTPUT;
   SET @V_NRLANCTONF = SUBSTRING(@V_NRLANCTONF, 11, 10);

   /* Busca o nmero do boleto */
   SET @V_CONCAT2 = 'BOLETRECEBER'+ @P_CDFILIPROC;
   EXEC NOVO_CODIGO @V_CONCAT2 , @P_SEQUENCIAL = @V_NRLANBOL OUTPUT, @P_QTDE = @V_QTPARCELAS;
   SET @V_NRLANBOL = SUBSTRING(@V_NRLANBOL, 11, 10);

   /*Verifica se existe taxa administrativa*/
   BEGIN
      SELECT @V_IDTIPORECE = MAX(IDTIPORECE),
             @V_CDTPAJUSTE = MAX(CDAJTXADMREC),
             @V_VRPETAXA   = MAX(VRTAXAADMI)
      FROM   TIPORECE
      WHERE  CDTIPORECE = @P_CDTIPORECE;
   END;

   SET @V_VRAJUSTE = 0;
   IF (@V_CDTPAJUSTE IS NOT NULL) AND (@V_VRPETAXA > 0) BEGIN
       SET @V_VRAJUSTE = ROUND(@V_VRPETAXA * @P_VRMOVIVEND / 100, 2);
   END;

   SET @V_CDCONTCORR  = '';
   SET @V_CDTIPOBAIXA = '';

   IF @V_IDTIPORECE IN ('3','4') BEGIN
      IF @V_IDTIPORECE = '4' BEGIN
         SELECT @V_CDCONTCORR  = MAX(CDREDUCONT),
                @V_CDTIPOBAIXA = MAX(CDTPBAIXAREC)
         FROM PARAVEND
         WHERE CDFILIAL = @P_FILIORIGEM;
      END

      IF (@V_CDCONTCORR = '') AND (@V_CDTIPOBAIXA = '') BEGIN
         SELECT @V_CDCONTCORR = MAX(CDREDUCONT),
                @V_CDTIPOBAIXA = MAX(CDTPBAIXAREC)
         FROM TIPORECE
         WHERE CDTIPORECE = @P_CDTIPORECE;
      END
   END;

   SELECT @V_NRINSJURCLIE = MAX(NRINSJURCLIE),
          @V_NMRAZSOCCLIE = MAX(NMRAZSOCCLIE)
   FROM   CLIENTE
   WHERE  CDCLIENTE = @P_CDCLIENTE;

   IF @P_NRCHEQUEVEND IS NOT NULL BEGIN
      INSERT INTO CHEQUERECE
     (NRCHEQUERECE, CDBANCHEQREC, CDAGECHEQREC, CDCNTCHEQREC,
      VRCHEQUERECE, NRCOMCHEQREC, DTRECECHEQUE, DTVENCHEQREC,
      CDCLIENTE,    IDTIPCHEQREC, NRCEDCHEQREC, NMCEDCHEQREC,
      IDSITCHEQREC, CDREDUCONT,   CDEMPRESA)
      VALUES
     (@P_NRCHEQUEVEND, @P_CDBANCHEQVEN, @P_CDAGECHEQVEN, @P_CDCNTCHEQVEN,
      @P_VRMOVIVEND,   '001',           @P_DTMOVIMCAIXA, @P_DTVENCIMENTO,
      @P_CDCLIENTE,    'P',             @V_NRINSJURCLIE, @V_NMRAZSOCCLIE,
      'A',             @V_CDCONTCORR,   @P_CDEMPRESA);
   END;

   SET @V_DESCCONTA = 'MOVIMENTAO DE CAIXA';

   EXEC GERA_CONTA  'S',
                     @P_CDEMPRESA,
                     @P_CDFILIPROC,
                     @P_FILIORIGEM,
                     @V_NRLANCTONF,
                     @V_NRLANBOL,
                     @P_VRMOVIVEND,       /*Valor da movimentao*/
                     @P_CDTIPOOPER,
                     @P_CDSERIE,
                     'C',                /*IDORIGDEST: Cliente*/
                     @P_CDCLIENTE,       /*Cliente padro*/
                     @P_DTMOVIMCAIXA,    /*DTEMISSAO*/
                     @P_DTMOVIMCAIXA,    /*DTENTRSAID*/
                     'A',                /*Status da nota*/
                     @P_CDVENDEDOR,      /*Vendedor*/
                     @P_DTMOVIMCAIXA,    /*DTLANCNF*/
                     @P_DTVENCIMENTO,    /*DTMOVCAIXA + Qtde. dias para recebimento*/
                     @P_CDTIPORECE,      /*Tipo de Recebimento*/
                     @V_DESCCONTA,       /*Descrio da conta*/
                     @P_NRCHEQUEVEND,    /*dados do cheque*/
                     @P_CDBANCHEQVEN,
                     @P_CDAGECHEQVEN,
                     @P_CDCNTCHEQVEN,
                     @P_NRINSJURCHEQ,
                     'A',                /*Status da conta*/
                     @V_CDTPAJUSTE,
                     @V_VRAJUSTE,
                     @P_CDOPERADOR,
                     @V_QTPARCELAS;

   IF @P_NRCHEQUEVEND IS NOT NULL BEGIN
       UPDATE MOVCAIXA
       SET   NRLANCTONF   = @V_NRLANCTONF,
             CDFILIALNF   = @P_CDFILIPROC
       WHERE CDFILIAL     = @P_FILIORIGEM AND
             DTMOVIMCAIXA = @P_DTMOVIMCAIXA AND
             CDTIPORECE   = @P_CDTIPORECE AND
             NRCHEQUEVEND = @P_NRCHEQUEVEND AND
             CDBANCHEQVEN = @P_CDBANCHEQVEN AND
             CDAGECHEQVEN = @P_CDAGECHEQVEN AND
             CDCNTCHEQVEN = @P_CDCNTCHEQVEN AND
             NRLANCTONF IS NULL AND
             (NRINSJURCHEQ IS NULL OR NRINSJURCHEQ = @P_NRINSJURCHEQ);
   END
   ELSE BEGIN
      IF (@P_SOMATORIO = '1') BEGIN /* Verifica o tipo de somatrio da tela */
         UPDATE MOVCAIXA
         SET NRLANCTONF = @V_NRLANCTONF,
             CDFILIALNF = @P_CDFILIPROC
         WHERE (NRSEQVENDA IN (SELECT M.NRSEQVENDA
                                FROM MOVCAIXA M, VENDA V
                               WHERE M.CDFILIAL = @P_FILIORIGEM
                                 AND M.DTMOVIMCAIXA = @P_DTMOVIMCAIXA
                                 AND M.CDTIPORECE = @P_CDTIPORECE
                                 AND V.CDCLIENTE = @P_CDCLIENTE
                                 AND M.CDFILIAL = V.CDFILIAL
                                 AND M.CDCAIXA = V.CDCAIXA
                                 AND M.NRSEQVENDA = V.NRSEQVENDA))
           AND CDFILIAL = @P_FILIORIGEM
           AND DTMOVIMCAIXA = @P_DTMOVIMCAIXA
           AND CDTIPORECE = @P_CDTIPORECE
           AND NRLANCTONF IS NULL
           AND QTPARCRECEB = @P_QTPARCELAS;
      END
      ELSE BEGIN
         UPDATE MOVCAIXA
         SET NRLANCTONF = @V_NRLANCTONF,
             CDFILIALNF = @P_CDFILIPROC
         WHERE CDFILIAL = @P_FILIORIGEM
           AND DTMOVIMCAIXA = @P_DTMOVIMCAIXA
           AND CDTIPORECE = @P_CDTIPORECE
           AND NRLANCTONF IS NULL
           AND QTPARCRECEB = @P_QTPARCELAS;
      END;
   END;

   /*Se o tipo de recebimento for dinheiro,cheque  gerada a baixa*/
   IF @V_IDTIPORECE in ('3','4') BEGIN
      EXEC GERA_BAIXA 'S',           @P_CDEMPRESA,   @P_FILIORIGEM,
                      @V_NRLANBOL,   @P_CDFILIPROC,  @P_DTMOVIMCAIXA,
                      @V_CDCONTCORR, @V_CDTIPOBAIXA, @P_CDOPERADOR;
   END;
END;
GO

-- VERSAO --
EXEC ATUVEROBJ 'EXPORTA_PDV_FINANC','5.07.009';
GO
